@@ -76,33 +76,41 @@ sub all_plugins_in_prereqs
                 if exists $exempt{$plugin};
             next if $plugin eq 'Dist::Zilla::Plugin::FinderCode';  # added automatically by dist builder
 
-            # the plugin should have been added to develop prereqs - look for
-            # an explicit :version requirement there
+            # plugins with a specific :version requirement are added to
+            # prereqs via an extra injected [Prereqs] plugin
             my $required_version = $bundle_plugin_prereqs->{find_meta($plugin)->name} // 0;
-            $required_version = any($required_version, re(qr/[^\d.]/));
 
             if (exists $additional{$plugin})
             {
+                # plugin was added in via an extra option, therefore the
+                # plugin should have been added to develop prereqs
                 ok(
                     exists $dist_meta->{prereqs}{develop}{requires}{$plugin},
                     $plugin . ' is a develop prereq of the distribution',
-                ) or diag 'got dist metadata: ', explain $dist_meta;
+                );
 
                 cmp_deeply(
                     $pluginbundle_meta->{prereqs}{runtime}{recommends},
                     superhashof({ $plugin => $required_version }),
                     $plugin . ' is a runtime recommendation of the plugin bundle',
-                ) or diag 'got plugin bundle metadata: ', explain $pluginbundle_meta;
+                );
             }
             else
             {
+                # plugin is a core requirement of the bundle
                 cmp_deeply(
                     $pluginbundle_meta->{prereqs}{runtime}{requires},
                     superhashof({ $plugin => $required_version }),
                     $plugin . ' is a runtime prereq of the plugin bundle',
-                ) or diag 'got plugin bundle metadata: ', explain $pluginbundle_meta;
+                );
             }
         }
+
+        if (not Test::Builder->new->is_passing)
+        {
+            diag 'got dist metadata: ', explain $dist_meta;
+            diag 'got plugin bundle metadata: ', explain $pluginbundle_meta;
+        }
     }
 } }
 
